Struct openssl::dh::Dh [−][src]
pub struct Dh<T>(_, _);Implementations
Creates a DH instance based upon the given primes and generator params.
This corresponds to DH_new and DH_set0_pqg.
Sets the private key on the DH object and recomputes the public key.
Generates DH params based on the given prime_len and a fixed generator value.
This corresponds to DH_generate_parameters_ex.
Generates a public and a private key based on the DH params.
This corresponds to DH_generate_key.
Deserializes a PEM-encoded PKCS#3 DHpararameters structure.
The input should have a header of -----BEGIN DH PARAMETERS-----.
This corresponds to PEM_read_bio_DHparams.
Deserializes a DER-encoded PKCS#3 DHparameters structure.
This corresponds to d2i_DHparams.
Requires OpenSSL 1.0.2 or newer.
Requires OpenSSL 1.0.2 or newer.
Requires OpenSSL 1.0.2 or newer.
Returns the prime p from the DH instance.
This corresponds to DH_get0_pqg.
Returns the prime q from the DH instance.
This corresponds to DH_get0_pqg.
Returns the generator from the DH instance.
This corresponds to DH_get0_pqg.
Methods from Deref<Target = DhRef<T>>
Serializes the parameters into a PEM-encoded PKCS#3 DHparameter structure.
The output will have a header of -----BEGIN DH PARAMETERS-----.
This corresponds to PEM_write_bio_DHparams.
Serializes the parameters into a DER-encoded PKCS#3 DHparameter structure.
This corresponds to i2d_DHparams.
Returns the public key from the DH instance.
This corresponds to DH_get0_key.
Computes a shared secret from the own private key and the given public_key.
This corresponds to DH_compute_key.
Returns the private key from the DH instance.
This corresponds to DH_get0_key.